function w = prcos(n)
%PRCOS Partial Raised Cosine window.
%  W = PRCOS(N) returns an N point partial raised cosine window where the first 
%  and last 10% of the N points have the cosine applied and the middle 80% are
%  unaffected (i.e., window values = 1).
%
%  Written by T. J. Collins III 
%  $Revision: 1.0 $  $Date: 2000/11/24   17:51  $

%  Create the window vector with the "middle 80%" built-in.

w = ones(n,1);

%  Do the first 10% of the window.

m = round((0.1)*n);
for i = 1:m
   w(i,:) = 0.5*(1 - cos(pi*i/m));
end

%  Do the last 10% of the window.

r = round((0.9)*n);
for i = r:n
   w(i,:) = 0.5*(1 - cos(pi*(n - i)/m));
end

% [EOF]  prcos.m